aboutsummaryrefslogtreecommitdiff
path: root/mesonbuild/backend/backends.py
diff options
context:
space:
mode:
authorPaolo Bonzini <pbonzini@redhat.com>2019-02-21 11:15:02 +0100
committerPaolo Bonzini <pbonzini@redhat.com>2019-03-02 09:07:54 +0100
commit4b5cf3f7c549412e60baa925a42c80dbf17ffdd7 (patch)
tree9eff04bc89d5f45aebb902289b5dd5bce170a618 /mesonbuild/backend/backends.py
parentf0b0bcf86d195cc65918eea0de2c92083ac39f3f (diff)
downloadmeson-4b5cf3f7c549412e60baa925a42c80dbf17ffdd7.zip
meson-4b5cf3f7c549412e60baa925a42c80dbf17ffdd7.tar.gz
meson-4b5cf3f7c549412e60baa925a42c80dbf17ffdd7.tar.bz2
interpreter: add "protocol" kwarg to test
This is the first step towards adding support for TAP.
Diffstat (limited to 'mesonbuild/backend/backends.py')
-rw-r--r--mesonbuild/backend/backends.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/mesonbuild/backend/backends.py b/mesonbuild/backend/backends.py
index 5062767..4d35d22 100644
--- a/mesonbuild/backend/backends.py
+++ b/mesonbuild/backend/backends.py
@@ -84,7 +84,7 @@ class ExecutableSerialisation:
class TestSerialisation:
def __init__(self, name, project, suite, fname, is_cross_built, exe_wrapper, is_parallel,
cmd_args, env, should_fail, timeout, workdir, extra_paths):
self.name = name
self.project_name = project
self.suite = suite
@@ -100,6 +100,7 @@ class TestSerialisation:
self.timeout = timeout
self.workdir = workdir
self.extra_paths = extra_paths
+ self.protocol = protocol
class OptionProxy:
def __init__(self, name, value):
@@ -756,7 +757,7 @@ class Backend:
raise MesonException('Bad object in test command.')
ts = TestSerialisation(t.get_name(), t.project_name, t.suite, cmd, is_cross,
exe_wrapper, t.is_parallel, cmd_args, t.env,
- t.should_fail, t.timeout, t.workdir, extra_paths)
+ t.should_fail, t.timeout, t.workdir, extra_paths, t.protocol)
arr.append(ts)
return arr
@@ -84,7 +84,7 @@ class ExecutableSerialisation:
class TestSerialisation:
def __init__(self, name, project, suite, fname, is_cross_built, exe_wrapper, is_parallel,
- cmd_args, env, should_fail, timeout, workdir, extra_paths):
+ cmd_args, env, should_fail, timeout, workdir, extra_paths, protocol):
self.name = name
self.project_name = project